@@ -55,7 +55,8 @@ class Freebox(IPlugin):
 				log.msg("idx  :  %s" % (rs['idx']))
 				log.msg("idx sec :  %s" % (rs['idx_sec']))
 				log.msg(" boy  :  %s" % (rs['boy']))
-				
+				if rs['idx_sec'] == "":
+					rs['idx_sec'] == "1"
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre  
